// Persistence of Vision Ray Tracer Scene Description File
// File: Inside.pov
// Vers: 3.1
// Desc: Inside.  Entry for IRTC
// Date: 22/11/00
// Auth: VoR
//

#version 3.1;

#declare Do_Rocks = 1;
#declare Do_Lotsatrees = 1;

#include "colors.inc"
#include "stones.inc"
//#include "textures.inc"

global_settings
{
  assumed_gamma 1.0 
  ambient_light 0.25
}


// ----------------------------------------
camera
{
  location  <0.0, 1.2, -25.0>
  direction 1.5*z
  right     3/4*x
  look_at   <0.0, 1.8,  0.0>
}

sky_sphere
{
  pigment
  {
    gradient y
    color_map { [0.0 color rgb 0.15] [ 0.27 color blue 0.1] [1.0 color rgb 0.08] }
  }
}

light_source
{
  0*x // light's position (translated below)
  color rgb <1,1,1>*0.2  // light's color
  translate <30, 30, -10>
}

// ----------------------------------------   
difference {
  plane { y, -1 pigment {color rgb <0.7,0.5,0.3>}}
  box {
    <-20,0,5.5> <20,-10,-20> pigment {Tan}
  }
}                                                           

#declare Water =
texture {
    pigment{ rgbf <0.1, 0.1, 0.3, 0.9> }
    normal {
        ripples 0.75
        frequency 10
    }
    finish {
        reflection 0.4
#version -1.0;
        refraction 0.5
        ior 1.33
    }
#version 3.1;
}

plane { y, -1.2 texture {Water scale <10,0.95,3> translate -z*10}}


//=======================================
// Rocks
//      
#ifdef (Do_Rocks)
union {
#declare i = 50;
#declare R = seed (1483);
#while (i > 0)
box {
  <-1,-1,-1> <1,1,1>
  scale <rand(R)*3,5+rand(R)*10,1+rand(R)*2>
  rotate z*rand(R)*5  
  rotate y*rand(R)*90
  #switch (rand(R))
  #range (0,0.25)
    texture {T_Stone25}
  #break
  #range (0.25,0.5)
    texture {T_Stone37}
  #break  
  #range (0.5,0.75)   
    texture {T_Stone38}
  #break  
  #range (0.75,1)
    texture {T_Stone5}
  #break    
  #end
  translate <20-rand(R)*40,0,40+rand(R)*40>
  #declare i = i - 1;
}
#end
}   
#end //Do_Rocks
                         
//************
// Trees                         
#ifdef (Do_Lotsatrees)
#include "veg.inc"
union {
#declare R = seed (5423);
#declare i = 50;
#while (i > 0)
union {
  #if (rand(R) > 0.5) 
    object{Tree1 scale 0.6+rand(R)*0.6 rotate y*rand(R)*360 translate <rand(R)*0.1,-3,rand(R)*0.1>}
    object{Tree2 scale 1.1-rand(R)*0.5 rotate <rand(R)*2,rand(R)*360,0> translate<rand(R)*0.1,-3,rand(R)*0.1>}
  #else
    object{Grantrae scale 1+rand(R)*0.4 rotate y*rand(R)*360 translate <rand(R)*0.1,0,rand(R)*0.1>}
  #end
  #declare H = rand(R)*7;
  sphere {<0,-2,0> 2 texture {T_Stone38} scale <H/3,H,H/3> translate -y*H}
  
  translate <10-rand(R)*20,H,15+rand(R)*20>
   
  #declare i = i - 1;    
}
#end

#declare i = 20;
#while (i > 0)
union {
  #if (rand(R) > 0.7) 
    object{Tree1 scale 0.6+rand(R)*0.6 rotate y*rand(R)*360 translate <rand(R)*0.1,-3,rand(R)*0.1>}
    object{Tree2 scale 1.1-rand(R)*0.5 rotate <rand(R)*2,rand(R)*360,0> translate<rand(R)*0.1,-3,rand(R)*0.1>}
  #else
    object{Grantrae scale 1+rand(R)*0.4 rotate y*rand(R)*360 translate <rand(R)*0.1,0,rand(R)*0.1>}
  #end
  #declare H = rand(R)*7;
  sphere {<0,-2,0> 2 texture {T_Stone38} scale <H/3,H,H/3> translate -y*H}
  
  translate <-5-rand(R)*20,H,rand(R)*7>
   
  #declare i = i - 1;    
}
#end

#declare i = 20;
#while (i > 0)
union {
  #if (rand(R) > 0.7) 
    object{Tree1 scale 0.6+rand(R)*0.6 rotate y*rand(R)*360 translate <rand(R)*0.1,-3,rand(R)*0.1>}
    object{Tree2 scale 1.1-rand(R)*0.5 rotate <rand(R)*2,rand(R)*360,0> translate<rand(R)*0.1,-3,rand(R)*0.1>}
  #else
    object{Grantrae scale 1+rand(R)*0.4 rotate y*rand(R)*360 translate <rand(R)*0.1,0,rand(R)*0.1>}
  #end
  #declare H = rand(R)*7;
  sphere {<0,-2,0> 2 texture {T_Stone38} scale <H/3,H,H/3> translate -y*H}
  
  translate <5+rand(R)*20,H,rand(R)*7>
   
  #declare i = i - 1;    
}
#end

}   
#end  //Do_Lotsatrees

//-------------------------------------------------------------------
#macro Reeds(XLen,YLen,AverageHeight,Radius)
#declare Z0 = seed(1000);
#declare Z1 = seed(1001);
#declare Z2 = seed(1002);
#declare Z3 = seed(1003);
#declare Z4 = seed(1003);
#declare Reeds_Texture=
texture{pigment{
        gradient x turbulence 0.1
        color_map{ [ 0.00 color YellowGreen      ]
                           [ 0.50 color MediumSpringGreen]
                           [ 1.00 color YellowGreen      ]}}
                finish {ambient 0.15 diffuse 0.85 phong 1} scale 0.1}
#macro Reed(ZHeight,ZRotate,YRotate)
 cone {<0,-1,0>,Radius,<0,ZHeight,0>,Radius/4  rotate<0,0,ZRotate> rotate<0,YRotate,0> }#end// of macro 
union{
#declare NrX = 0;     // start X
#declare EndNrX = 3*XLen; // end   X
#while (NrX< EndNrX)
 #declare NrZ = 0;     // start Z
 #declare EndNrZ = 3*YLen; // end   Z
 #while (NrZ< EndNrZ)
   object{Reed(AverageHeight+rand(Z0)*0.5,rand(Z1)*20,rand(Z2)*180) translate<NrX*0.10+rand(Z3)*0.1,0,NrZ*0.10+rand(Z4)*0.1>}  #declare NrZ = NrZ + 1;  // next NrZ
 #end

#declare NrX = NrX + 1;  // next NrX
#end // --------------- end of loop 
texture{Reeds_Texture}
}#end // end of Reeds 

object{ Reeds(10.00,2.00, 2.75,0.02) //(XLen,YLen,AverageHeight,Radius)
        scale 1
        translate<-5,-1,4>}
 // Reeds
 
object{ Reeds(3.00,4.00, 1.75,0.02) //(XLen,YLen,AverageHeight,Radius)
        scale 1
        translate<4,-1,1>}
 // Reeds
object{ Reeds(20.00,4.00, 0.8,0.02) //(XLen,YLen,AverageHeight,Radius)
        scale 1
        translate<-8,-1,0>} 
 
#include "portal.pov"                                                    
union {
  object {Portal rotate -x*90 rotate y*180}
  light_source
  {
    0*x // light's position (translated below)
    color rgb <1,1,0.7>*1.5  // light's color
    looks_like {sphere {0*x 0.2 texture{pigment {White} finish {ambient 100}}}}
    translate <0, 2.8, 1>
  }
                        
  light_source
  {
    0*x // light's position (translated below)    
    color rgb <1,1,0.7>*0.8  // light's color
    looks_like {sphere {0*x 0.1 texture{pigment {White} finish {ambient 100}}}}    
    spotlight 
    radius 50
    falloff 70
    tightness 8
    point_at <0.2,1,1>
    translate <1.4, 0.3, -1.7>
  }

  translate <0,-0.7,5.5>
}                                                    

//***********************************


sphere {
  <0,0,0> 1
  texture {pigment {
// create a texture that lays an image's colors onto a surface
// image maps into X-Y plane from <0,0,0> to <1,1,0>
image_map
{
  gif "moonmap.gif" // the file to read (iff/gif/tga/png/sys)
  map_type 1 // 0=planar, 1=spherical, 2=cylindrical, 5=torus
  interpolate 2 // 0=none, 1=linear, 2=bilinear, 4=normalized distance
  // [filter N V] // N=all or color index # (0...N), V= value (0.0...1.0)
  // [transmit N V] // N=all or color index # (0...N), V= value (0.0...1.0)
  // [use_color | use_index]
  // [once]
} // image_map
}//pigment
finish {ambient 0.15 diffuse 15}
}//texture
  scale 1000000
  translate <2000,6000000,20000000>

}